<?xml version="1.0" encoding="UTF-8"?>
<gui name="artikulate_editor"
     version="1"
     xmlns="http://www.kde.org/standards/kxmlgui/1.0"
     xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
     xsi:schemaLocation="http://www.kde.org/standards/kxmlgui/1.0
                         http://www.kde.org/standards/kxmlgui/1.0/kxmlgui.xsd" >

  <MenuBar>
    <Menu name="file" >
      <Action name="save" />
      <Action name="export_ghns" />
    </Menu>
    <Menu name="settings" >
      <Action name="settings" />
    </Menu>
  </MenuBar>
</gui>
